==> pinot-spi-0.11.0-sources.jar: org/apache/pinot/spi/config/instance/InstanceDataManagerConfig.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.spi.config.instance;

import org.apache.pinot.spi.env.PinotConfiguration;
import org.apache.pinot.spi.utils.ReadMode;


public interface InstanceDataManagerConfig {
  PinotConfiguration getConfig();

  String getInstanceId();

  String getInstanceDataDir();

  String getConsumerDir();

  String getInstanceSegmentTarDir();

  String getInstanceBootstrapSegmentDir();

  String getSegmentStoreUri();

  ReadMode getReadMode();

  String getSegmentFormatVersion();

  String getAvgMultiValueCount();

  boolean isEnableSplitCommit();

  boolean isEnableSplitCommitEndWithMetadata();

  boolean isRealtimeOffHeapAllocation();

  boolean isDirectRealtimeOffHeapAllocation();

  int getMaxParallelSegmentBuilds();

  int getMaxParallelSegmentDownloads();

  String getSegmentDirectoryLoader();

  long getErrorCacheSize();

  boolean isStreamSegmentDownloadUntar();

  long getStreamSegmentDownloadUntarRateLimit();
}

==> pinot-spi-0.12.1-sources.jar: org/apache/pinot/spi/config/instance/InstanceDataManagerConfig.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.spi.config.instance;

import org.apache.pinot.spi.env.PinotConfiguration;
import org.apache.pinot.spi.utils.ReadMode;


public interface InstanceDataManagerConfig {
  PinotConfiguration getConfig();

  String getInstanceId();

  String getInstanceDataDir();

  String getConsumerDir();

  String getInstanceSegmentTarDir();

  String getInstanceBootstrapSegmentDir();

  String getSegmentStoreUri();

  ReadMode getReadMode();

  String getSegmentFormatVersion();

  String getAvgMultiValueCount();

  boolean isEnableSplitCommit();

  boolean isEnableSplitCommitEndWithMetadata();

  boolean isRealtimeOffHeapAllocation();

  boolean isDirectRealtimeOffHeapAllocation();

  int getMaxParallelSegmentBuilds();

  int getMaxParallelSegmentDownloads();

  String getSegmentDirectoryLoader();

  long getErrorCacheSize();

  boolean isStreamSegmentDownloadUntar();

  long getStreamSegmentDownloadUntarRateLimit();

  int getDeletedSegmentsCacheSize();

  int getDeletedSegmentsCacheTtlMinutes();

  String getSegmentPeerDownloadScheme();
}
